==> ejc-supbid-api-3.0.1-20211213.092621-44-sources.jar: com/ejianc/business/supbid/material/vo/SchemeDetailVO.java <==
package com.ejianc.business.supbid.material.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报价明细实体
 * 
 * @author generator
 * 
 */
@ApiModel("报价明细实体")
public class SchemeDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("方案主键")
    private java.lang.Long schemeId;
    @ApiModelProperty("材料ID")
    private java.lang.String sourceMaterialId;
    @ApiModelProperty("材料名称")
    private java.lang.String materialName;
    @ApiModelProperty("材料编码")
    private java.lang.String materialCode;
    @ApiModelProperty("材料分类ID")
    private java.lang.String sourceMaterialTypeId;
    @ApiModelProperty("材料分类名称")
    private java.lang.String materialTypeName;
    @ApiModelProperty("单位")
    private java.lang.String unit;
    @ApiModelProperty("规格型号")
    private java.lang.String spec;
    @ApiModelProperty("品牌")
    private java.lang.String brand;
    @ApiModelProperty("计量方式(0-理计,1-过磅,2-点数)")
    private java.lang.Integer calculateType;
    @ApiModelProperty("数量")
    private java.math.BigDecimal num;
    @ApiModelProperty("税率")
    private java.math.BigDecimal rate;
    @ApiModelProperty("备注")
    private java.lang.String memo;
    @ApiModelProperty("供货品牌")
    private java.lang.String supplierBrand;
    @ApiModelProperty("单价")
    private java.math.BigDecimal price;
    @ApiModelProperty("单价(含税)")
    private java.math.BigDecimal priceTax;
    @ApiModelProperty("总额")
    private java.math.BigDecimal money;
    @ApiModelProperty("总额(含税)")
    private java.math.BigDecimal moneyTax;
    @ApiModelProperty("税额")
    private java.math.BigDecimal tax;
    @ApiModelProperty("备注")
    private java.lang.String supplierMemo;
    

    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案主键
     */
    public java.lang.Long getSchemeId() {
        return schemeId;
    }

    /**
     * 方案主键
     */
    public void setSchemeId(java.lang.Long schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 材料ID
     */
    public java.lang.String getSourceMaterialId() {
        return sourceMaterialId;
    }

    /**
     * 材料ID
     */
    public void setSourceMaterialId(java.lang.String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public java.lang.String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setSourceMaterialTypeId(java.lang.String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    /**
     * 材料分类名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public java.lang.Integer getCalculateType() {
        return calculateType;
    }

    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public void setCalculateType(java.lang.Integer calculateType) {
        this.calculateType = calculateType;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getRate() {
        return rate;
    }

    /**
     * 税率
     */
    public void setRate(java.math.BigDecimal rate) {
        this.rate = rate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 供货品牌
     */
    public java.lang.String getSupplierBrand() {
        return supplierBrand;
    }

    /**
     * 供货品牌
     */
    public void setSupplierBrand(java.lang.String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税)
     */
    public java.math.BigDecimal getPriceTax() {
        return priceTax;
    }

    /**
     * 单价(含税)
     */
    public void setPriceTax(java.math.BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    /**
     * 总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public java.lang.String getSupplierMemo() {
        return supplierMemo;
    }

    /**
     * 备注
     */
    public void setSupplierMemo(java.lang.String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    
}

==> ejc-supbid-api-3.0.1-20220919.095448-196-sources.jar: com/ejianc/business/supbid/material/vo/SchemeDetailVO.java <==
package com.ejianc.business.supbid.material.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 报价明细实体
 * 
 * @author generator
 * 
 */
@ApiModel("报价明细实体")
public class SchemeDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("方案主键")
    private java.lang.Long schemeId;
    @ApiModelProperty("材料ID")
    private java.lang.String sourceMaterialId;
    @ApiModelProperty("材料名称")
    private java.lang.String materialName;
    @ApiModelProperty("材料编码")
    private java.lang.String materialCode;
    @ApiModelProperty("材料分类ID")
    private java.lang.String sourceMaterialTypeId;
    @ApiModelProperty("材料分类名称")
    private java.lang.String materialTypeName;
    @ApiModelProperty("单位")
    private java.lang.String unit;
    @ApiModelProperty("规格型号")
    private java.lang.String spec;
    @ApiModelProperty("品牌")
    private java.lang.String brand;
    @ApiModelProperty("计量方式(0-理计,1-过磅,2-点数)")
    private java.lang.Integer calculateType;
    @ApiModelProperty("数量")
    private java.math.BigDecimal num;
    @ApiModelProperty("税率")
    private java.math.BigDecimal rate;
    @ApiModelProperty("备注")
    private java.lang.String memo;
    @ApiModelProperty("供货品牌")
    private java.lang.String supplierBrand;
    @ApiModelProperty("单价")
    private java.math.BigDecimal price;
    @ApiModelProperty("单价(含税)")
    private java.math.BigDecimal priceTax;
    @ApiModelProperty("总额")
    private java.math.BigDecimal money;
    @ApiModelProperty("总额(含税)")
    private java.math.BigDecimal moneyTax;
    @ApiModelProperty("税额")
    private java.math.BigDecimal tax;
    @ApiModelProperty("备注")
    private java.lang.String supplierMemo;

    @ApiModelProperty("明细税率（不可修改）")
    private java.math.BigDecimal detailRate;

    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }

    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案主键
     */
    public java.lang.Long getSchemeId() {
        return schemeId;
    }

    /**
     * 方案主键
     */
    public void setSchemeId(java.lang.Long schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 材料ID
     */
    public java.lang.String getSourceMaterialId() {
        return sourceMaterialId;
    }

    /**
     * 材料ID
     */
    public void setSourceMaterialId(java.lang.String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public java.lang.String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setSourceMaterialTypeId(java.lang.String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    /**
     * 材料分类名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public java.lang.Integer getCalculateType() {
        return calculateType;
    }

    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public void setCalculateType(java.lang.Integer calculateType) {
        this.calculateType = calculateType;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getRate() {
        return rate;
    }

    /**
     * 税率
     */
    public void setRate(java.math.BigDecimal rate) {
        this.rate = rate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 供货品牌
     */
    public java.lang.String getSupplierBrand() {
        return supplierBrand;
    }

    /**
     * 供货品牌
     */
    public void setSupplierBrand(java.lang.String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税)
     */
    public java.math.BigDecimal getPriceTax() {
        return priceTax;
    }

    /**
     * 单价(含税)
     */
    public void setPriceTax(java.math.BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    /**
     * 总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public java.lang.String getSupplierMemo() {
        return supplierMemo;
    }

    /**
     * 备注
     */
    public void setSupplierMemo(java.lang.String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    
}
